@@ -153,7 +153,7 @@ impl<'a> TableMapEvent<'a> {
     pub fn iter_optional_meta(&'a self) -> OptionalMetadataIter<'a> {
         OptionalMetadataIter {
             columns: &self.columns_type,
-            data: self.columns_metadata.as_bytes(),
+            data: self.optional_metadata.as_bytes(),
         }
     }
 
@@ -937,7 +937,7 @@ pub enum OptionalMetadataField<'a> {
     /// See [`OptionalMetadataFieldType::SIGNEDNESS`].
     Signedness(
         /// Flags indicating unsignedness for every numeric column.
-        &'a BitSlice<Lsb0, u8>,
+        &'a BitSlice<Msb0, u8>,
     ),
     /// See [`OptionalMetadataFieldType::DEFAULT_CHARSET`].
     DefaultCharset(DefaultCharset<'a>),
@@ -959,9 +959,15 @@ pub enum OptionalMetadataField<'a> {
     EnumAndSetDefaultCharset(DefaultCharset<'a>),
     /// See [`OptionalMetadataFieldType::ENUM_AND_SET_COLUMN_CHARSET`].
     EnumAndSetColumnCharset(ColumnCharsets<'a>),
+    /// See [`OptionalMetadataFieldType::COLUMN_VISIBILITY`].
+    ColumnVisibility(
+        /// Flags indicating visibility for every numeric column.
+        &'a BitSlice<Msb0, u8>,
+    ),
 }
 
 /// Iterator over fields of an optional metadata.
+#[derive(Debug)]
 pub struct OptionalMetadataIter<'a> {
     columns: &'a RawSeq<'a, u8, ColumnType>,
     data: &'a [u8],
@@ -982,7 +988,7 @@ impl<'a> OptionalMetadataIter<'a> {
                 ));
             }
         };
-        self.data = &self.data[..l];
+        self.data = &self.data[l..];
         Ok((RawConst::new(t), v))
     }
 
@@ -997,6 +1003,10 @@ impl<'a> OptionalMetadataIter<'a> {
         self.read_tlv().map(Some).transpose()
     }
 
+    fn num_columns(&self) -> usize {
+        self.columns.0.len()
+    }
+
     fn count_columns(&self, f: fn(&ColumnType) -> bool) -> usize {
         self.columns
             .0
@@ -1031,7 +1041,7 @@ impl<'a> Iterator for OptionalMetadataIter<'a> {
                             }
 
                             let flags = BitSlice::from_slice(flags).expect("the slice is too big");
-                            Ok(OptionalMetadataField::Signedness(&flags[..num_flags_bytes]))
+                            Ok(OptionalMetadataField::Signedness(&flags[..num_numeric]))
                         }
                         DEFAULT_CHARSET => Ok(OptionalMetadataField::DefaultCharset(v.parse(())?)),
                         COLUMN_CHARSET => Ok(OptionalMetadataField::ColumnCharset(v.parse(())?)),
@@ -1051,6 +1061,22 @@ impl<'a> Iterator for OptionalMetadataIter<'a> {
                         ENUM_AND_SET_COLUMN_CHARSET => {
                             Ok(OptionalMetadataField::EnumAndSetColumnCharset(v.parse(())?))
                         }
+                        COLUMN_VISIBILITY => {
+                            let num_columns = self.num_columns();
+                            let num_flags_bytes = (num_columns + 7) / 8;
+                            let flags: &[u8] = v.parse(num_flags_bytes)?;
+
+                            if !v.is_empty() {
+                                return Err(io::Error::new(
+                                    io::ErrorKind::Other,
+                                    "bytes remaining on stream",
+                                ));
+                            }
+
+                            let flags = BitSlice::from_slice(flags).expect("the slice is too big");
+                            let flags = &flags[..num_columns];
+                            Ok(OptionalMetadataField::ColumnVisibility(flags))
+                        }
                     },
                     Err(_) => Err(io::Error::new(
                         io::ErrorKind::InvalidData,
