@@ -23,10 +23,12 @@ macro_rules! impl_from_value {
 }
 
 pub mod bigdecimal;
+pub mod bigdecimal03;
 pub mod bigint;
 pub mod chrono;
 pub mod decimal;
 pub mod time;
+pub mod time03;
 pub mod uuid;
 
 lazy_static::lazy_static! {
